# Define the RPM header details
#
Summary: A window manager for the X Window System.
Name: WindowMaker
Version: 0.80.0
Release: 9.3
License: GPL
Group: User Interface/Desktops
URL: http://www.windowmaker.org/
BuildRequires: automake15
BuildRequires: autoconf253

# Some version numbers
#
%define libdockapp_ver 0.4.0
%define automake_ver -1.5
%define autoconf_ver -2.53


# The one and only true source...
# Also pull in libdockapp that a number of common dock apps use
# Add in some eyecandy
#
Source0: WindowMaker-%{version}.tar.gz
Source1: http://largo.windowmaker.org/files/libdockapp-%{libdockapp_ver}.tar.gz
# Source2: WindowMaker-0.80.0-Largo-Themes.tar.gz


# Additional patchs for the eastern folk
#
# XIM support patch (http://www.sh.rim.or.jp/~ssato/wm-i18n/index-e.html)
# 
Patch1: WindowMaker-0.80.0-XIM.patch

# Patch in the extra themes
#
# Patch2: WindowMaker-0.80.0-Extra-Themes.patch

Patch3: WindowMaker-0.80.1-width-height.patch


BuildRoot: %{_tmppath}/%{name}-%{version}-root
Requires: cpp
Provides: windowmanager


%description
Window Maker is an X11 window manager which emulates the look and feel
of the NeXTSTEP (TM) graphical user interface. It is relatively fast,
feature rich, and easy to configure and use. Window Maker is part of
the official GNU project, which means that Window Maker can
interoperate with other GNU projects, such as GNOME.

Window Maker allows users to switch themes 'on the fly,' as well as
place favorite applications on either an application dock (similar to
AfterStep Wharf) or on a workspace dock (a 'clip' which extends the
application dock's usefulness).

%package -n WindowMaker-libs
Group: System Environment/Libraries
Summary: Window Maker libraries.
Obsoletes: libwraster,libwraster-devel


%description -n WindowMaker-libs
The WindowMaker-libs package contains libraries for the Window Maker
desktop. You need to install this package if you are installing
Window Maker and/or wmakerconf.

%prep
# Call setup to unpack the sources by number
# %setup is a complex creature. refer to 
# http://www.rpm.org/RPM-HOWTO/build.html (section 6.3)
#
# %setup -q -a1 -b2
%setup -q -a1

# XIM support patch
#
%patch1 -p1

# Add in some 'cute' themes
#
# %patch2 -p1

%patch3 -p1 -b .width-height


# Adjust menu paths as they are hard coded in the original distribution
# to /usr/local.
#
for file in WindowMaker/*menu*; do
	if [ -r $file ]; then
		sed -e 's/\/usr\/local\/GNUstep/\/usr\/lib\/GNUstep/g;
			s/\/usr\/local\/share\/WindowMaker/\/usr\/share\/WindowMaker/g;
			s/\/usr\/local\/Acrobat3\/bin\/acroread/acroread/g;' < $file > $file.tmp;
		mv $file.tmp $file;
	fi;
done;

# This is basically what autogen.sh does but we'll do it here
# for development purposes. Besides, it'll annoy someone enough
# to eventually quieten the warnings and then we can all be
# happy again
#
# Oh joy. automake 1.4 doesn't work with the default configure.ac
# We'll be shipping 1.4 as 'automake' and 1.5 as 'automake-1.5'
# Similarly autoconf 2.53 is required. This is a RHAT distribution
# quirk. I need to hurt someone now.
#
libtoolize --copy --force
aclocal%{automake_ver} -I . $ACLOCAL_FLAGS    
autoheader%{autoconf_ver}
automake%{automake_ver} --add-missing    
autoconf%{autoconf_ver}


%build
LINGUAS="cs da de el es fi fr gl hr it ja ko nl no pl pt ro ru se sk tr zh_CN zh_TW.Big5 "
NLSDIR=/usr/share/locale
export NLSDIR LINGUAS


# Humm,... better shuffle the sysconfdir to the X11 equiv.
#
%define _sysconfdir /etc/X11

# Finally get get around to configuring the package.
# FHS standard (http://www.pathname.com/fhs - section 4.4.1)
#
%configure \
	--prefix=%{_prefix} \
	--exec-prefix=%{_exec_prefix} \
	--bindir=%{_bindir} \
	--sbindir=%{_sbindir} \
	--sysconfdir=%{_sysconfdir} \
	--datadir=%{_datadir} \
	--includedir=%{_includedir} \
	--libdir=%{_libdir} \
	--libexecdir=%{_libexecdir} \
	--localstatedir=%{_localstatedir} \
	--sharedstatedir=%{_sharedstatedir} \
	--mandir=%{_mandir} \
	--infodir=%{_infodir} \
	--enable-newstyle \
	--enable-xim \
	--enable-kde \
	--enable-gnome \
	--enable-openlook \
	--with-appspath=/usr/lib/GNUstep/Apps \
	--enable-shared=yes \
	--enable-static=no \
	--enable-usermenu \
	--with-pic


# gettext-0.10.38ize for zh_TW.Big5.po
#
( cd po; \
  make WindowMaker.pot; \
  OLD_PO_FILE_INPUT=yes msgmerge zh_TW.Big5.po WindowMaker.pot > new.po; \
  mv new.po zh_TW.Big5.po; \

  cd ../WPrefs.app/po; \
  make WPrefs.pot; \
  OLD_PO_FILE_INPUT=yes msgmerge zh_TW.Big5.po WPrefs.pot > new.po; \
  mv new.po zh_TW.Big5.po; \
)

# Build the WindowMaker distribution
#
make


# build libdockapp
#
( pushd .
  cd libdockapp-%{libdockapp_ver}
  libtoolize --copy --force
  aclocal -I .
  automake --add-missing
  autoconf
  %configure
  make
  popd
)


%install
rm -rf $RPM_BUILD_ROOT
make install \
	DESTDIR=$RPM_BUILD_ROOT \
	NLSDIR=/usr/share/locale 

for i in $(ls */README) ; do
    echo $i | sed -e "s|\(.*\)/\(.*\)|\2\.\1|" | xargs cp $i
done


# Hook up gdm (add in file that will add in windowmaker as a
# selectable window manager in the gdm enviroment
# (effectively "exec /etc/X11/xdm/Xsession kde")
#
echo "#!/bin/sh" > Window\ Maker
echo "exec /etc/X11/xdm/Xsession wmaker" >> Window\ Maker
mkdir -p $RPM_BUILD_ROOT/etc/X11/gdm/Sessions/
install -m 755 Window\ Maker $RPM_BUILD_ROOT/etc/X11/gdm/Sessions/


# Ok better sort out the locale files now and package the results
# for the %files section later on
#
%find_lang  WindowMaker
%find_lang  WPrefs
cat WindowMaker.lang WPrefs.lang > mofiles


# Ok now that the native Windowmaker stuff is done lets
# take a look at libdockapp
#
( pushd .
  cd libdockapp-%{libdockapp_ver}
  make install \
	DESTDIR=$RPM_BUILD_ROOT
  popd
)


%clean
rm -rf $RPM_BUILD_ROOT


%post -p /sbin/ldconfig


%postun -p /sbin/ldconfig


%post -p /sbin/ldconfig -n WindowMaker-libs


%postun -p /sbin/ldconfig -n WindowMaker-libs


%files -f mofiles
# Refer to /usr/lib/rpm/macros for the %{definitions}
# used below
#
%defattr(-,root,root)
%dir %{_sysconfdir}/WindowMaker
%config %{_sysconfdir}/WindowMaker/*
%doc AUTHORS BUGFORM BUGS ChangeLog NEWS FAQ* README
%doc TODO MIRRORS README*
%{_bindir}/*
%{_libdir}/GNUstep/Apps/WPrefs.app
%{_datadir}/WindowMaker
%{_datadir}/WINGs
%{_sysconfdir}/gdm/Sessions/*
%{_mandir}/*/*


%files -n WindowMaker-libs
%defattr(-,root,root)
%{_libdir}/lib*
%{_includedir}/*


%changelog
* Thu Jan 30 2003 Havoc Pennington <hp@redhat.com> 0.80.0-9.3
- unbreak the image loader patch

* Wed Dec  4 2002 Havoc Pennington <hp@redhat.com>
- patch to handle theme images with bad width/height

* Sun Apr 13  2002 Philip Copeland <bryce@redhat.com> <0.80.0-8>
- Humm,... destructions to remove the iconsets/themes
  apparently the Gnome/KDE ones are sufficient.

* Wed Apr 10 2002 Philip Copeland <bryce@redhat.com> <0.80.0-8>
- fixed %postun
- Shortened the Licence to GPL2

* Sun Mar 24 2002 Philip Copeland <bryce@redhat.com> <0.80.0-7>
- Finally got some time to add in Largo's new themes
- Made a small icon pack from other stuff Largo put together
- Updated the XIM patch.

* Thu Mar 14 2002 Philip Copeland <bryce@redhat.com> <0.80.0-7>
- Humm,.. automake 1.4 is not good. must use 1.5 and
  the mess that entails
- Added in a few more BuildRequires

* Tue Feb 19 2002 Philip Copeland <bryce@redhat.com> <0.80.0-6>
- Enabled the XIM patch again (new update)
- Updated the windowmaker-0.80.0.tar.gz arhive to latest CVS

* Wed Feb 13 2002 Philip Copeland <bryce@redhat.com> <0.80.0-5>
- Eeek, after talking with Alfredo looks like I
  shouldn't be using 0.80.1 as a version number
  quick rename to 0.80.0-xx

* Fri Feb 08 2002 Philip Copeland <bryce@redhat.com> <0.80.0-4>
- Started adding some dockapps that people might
  want to have on the dock bar.
  wmapc - useful for those that use laptops.
  wmix  - an intresting sound mixer dock app, tv
          style audio level meters.

* Wed Feb 06 2002 Philip Copeland <bryce@redhat.com> <0.80.0-3>
- Well looks like the XIM patch causes problems.
  Dropped out XIM support.
  (https://bugzilla.redhat.com/bugzilla/show_bug.cgi?id=59375)

* Wed Feb 06 2002 Philip Copeland <bryce@redhat.com> <0.80.0-2>
- *Mutter* autoheader has different behaviour on the
  i386 than it does on alpha. Removed autoheader
  from the libdockapp portion of the build.

* Wed Feb 06 2002 Philip Copeland <bryce@redhat.com> <0.80.0-1>
- Prettified the rpm spec file and heavily commented
  it. Hopefully mere mortals and fiddle with it now.
- Pulled in libdockapp as it's used by a number of
  WM dock apps. As it's so small, I've bundled it
  with the main WindowMaker-libs binary rpm.
- Under torture, relented and added in the XIM
  support patch. No idea if it actually works as I
  don't use japanese. (See Patch1 comment for URL)

* Fri Feb 01 2002 Philip Copeland <bryce@redhat.com> <0.80.0-0> initial tree
- Create prestine CVS build with no patchs applied.
  Just intrested in getting the pathnames in the 
  correct places for the moment. All hail the FHS.
  (http://www.pathname.com/fhs/pub/fhs-2.2.pdf
  section 4.4.1)
